@@ -294,6 +294,7 @@ void countdown_home_widget_edit_event (GtkWidget *button, GdkEventButton *event,
     GtkWidget *toggleYears, *toggleWeeks, *toggleDays, *toggleHours, *toggleMinutes;
     GtkWidget *displayCaption;
 	GtkWidget *removePassedButton, *removePassedCaption;
+	GtkTreeModel *sortModel;
 	GtkTreeIter iter;
     GtkSizeGroup *group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
@@ -381,7 +382,13 @@ void countdown_home_widget_edit_event (GtkWidget *button, GdkEventButton *event,
 		g_object_set (scroll, "vscrollbar-policy", GTK_POLICY_NEVER, NULL);
 	}
     
-	if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->priv->entries), &iter, NULL, index)) {
+	sortModel = gtk_tree_model_sort_new_with_model (GTK_TREE_MODEL (self->priv->entries));
+	
+	if (self->priv->sortByDate) {
+		gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (sortModel), 3, GTK_SORT_ASCENDING);
+	}
+	
+	if (gtk_tree_model_iter_nth_child (sortModel, &iter, NULL, index)) {
 		gchar *titleText, *dateText, *timeText;
 		gboolean tYears, tWeeks, tDays;
 		gboolean tHours, tMinutes;
@@ -391,7 +398,7 @@ void countdown_home_widget_edit_event (GtkWidget *button, GdkEventButton *event,
 		GDate date;
 		gint time;
 		
-		gtk_tree_model_get (GTK_TREE_MODEL (self->priv->entries), &iter, 0, &titleText, 1, &dateText, 2, &timeText, 4, &tYears, 5, &tWeeks, 6, &tDays, 7, &tHours, 8, &tMinutes, 9, &removePassed, -1);
+		gtk_tree_model_get (sortModel, &iter, 0, &titleText, 1, &dateText, 2, &timeText, 4, &tYears, 5, &tWeeks, 6, &tDays, 7, &tHours, 8, &tMinutes, 9, &removePassed, -1);
 		
 		g_date_set_parse (&date, dateText);
 		year = g_date_get_year (&date);
@@ -446,15 +453,19 @@ void countdown_home_widget_edit_event (GtkWidget *button, GdkEventButton *event,
         tHours = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (toggleHours));
 		removePassed = hildon_check_button_get_active (HILDON_CHECK_BUTTON (removePassedButton));
 
-		if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->priv->entries), &iter, NULL, index)) {
-			gtk_list_store_set (GTK_LIST_STORE (self->priv->entries), &iter, 0, title, 1, printDate, 2, compTime, 3, sortTime, -1);
-			gtk_list_store_set (GTK_LIST_STORE (self->priv->entries), &iter, 4, tYears, 5, tWeeks, 6, tDays, 7, tHours, 8, tMinutes, 9, removePassed, -1);
+		if (gtk_tree_model_iter_nth_child (sortModel, &iter, NULL, index)) {
+			GtkTreeIter childIter;
+			gtk_tree_model_sort_convert_iter_to_child_iter (GTK_TREE_MODEL_SORT (sortModel),
+								&childIter,
+								&iter);
+			gtk_list_store_set (self->priv->entries, &childIter, 0, title, 1, printDate, 2, compTime, 3, sortTime, -1);
+			gtk_list_store_set (self->priv->entries, &childIter, 4, tYears, 5, tWeeks, 6, tDays, 7, tHours, 8, tMinutes, 9, removePassed, -1);
 			
 			if (position < total) {
 				gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->priv->entries), &pos, NULL, position);
-				gtk_list_store_move_before (self->priv->entries, &iter, &pos);
+				gtk_list_store_move_before (self->priv->entries, &childIter, &pos);
 			} else {
-				gtk_list_store_move_before (self->priv->entries, &iter, NULL);
+				gtk_list_store_move_before (self->priv->entries, &childIter, NULL);
 			}
 		}
 
@@ -465,8 +476,12 @@ void countdown_home_widget_edit_event (GtkWidget *button, GdkEventButton *event,
 		countdown_home_widget_write_settings (self);
 		countdown_home_widget_update_content (self);
     } else if (response == GTK_RESPONSE_NO) {
-		if (gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->priv->entries), &iter, NULL, index)) {
-			gtk_list_store_remove (self->priv->entries, &iter);
+		if (gtk_tree_model_iter_nth_child (sortModel, &iter, NULL, index)) {
+			GtkTreeIter childIter;
+			gtk_tree_model_sort_convert_iter_to_child_iter (GTK_TREE_MODEL_SORT (sortModel),
+								&childIter,
+								&iter);
+			gtk_list_store_remove (self->priv->entries, &childIter);
 		}
 		countdown_home_widget_write_settings (self);
 		countdown_home_widget_update_content (self);
